/*
 * File: DrawFace1.java
 * --------------------
 * This program draw an abstract picture of a face on the canvas,
 * using procedural decomposition.
 */

package demos;

import acm.graphics.*;
import acm.program.*;

/**
 * This program draws an abstract picture of a face on the canvas. 
 * This version of the program decomposes the problem by defining
 * a set of procedures.
 */

@SuppressWarnings("serial")
public class DrawFace1 extends GraphicsProgram {

	/** Runs the program */
	public void run() {
		drawFace(getWidth() / 2, getHeight() / 2, 
				FACE_WIDTH, FACE_HEIGHT);
	}

	/**
	 * Draws a face centered at the point (x, y) with the specified 
	 * width and height
	 */
	private void drawFace(double x, double y, 
			double width, double height) {
		drawOutline(x, y, width, height);
		drawEye(x - width / 4, y - height / 4, 
				width * EYE_WIDTH, height * EYE_HEIGHT);
		drawEye(x + width / 4, y - height / 4, 
				width * EYE_WIDTH, height * EYE_HEIGHT);
		drawNose(x, y, 
				width * NOSE_WIDTH, height * NOSE_HEIGHT);
		drawMouth(x, y + height / 4, 
				width * MOUTH_WIDTH, height * MOUTH_HEIGHT);
	}

	/**
	 * Draws the outline of a face centered at the point (x, y) 
	 * with the specified width and height
	 */
	private void drawOutline(double x, double y, 
			double width, double height) {
		add(new GOval(x - width / 2, y - height / 2, width, height));
	}

	/**
	 * Draws an eye centered at the point (x, y) with the 
	 * specified width and height
	 */
	private void drawEye(double x, double y, 
			double width, double height) {
		add(new GOval(x - width / 2, y - height / 2, width, height));
	}

	/**
	 * Draws a nose centered at the point (x, y) with the 
	 * specified width and height. The nose is a triangular polygon.
	 */
	private void drawNose(double x, double y, 
			double width, double height) {
		GPolygon nose = new GPolygon();
		nose.addVertex(0, -height / 2);
		nose.addVertex(width / 2, height / 2);
		nose.addVertex(-width / 2, height / 2);
		add(nose, x, y);
	}

	/**
	 * Draws an eye centered at the point (x, y) with the 
	 * specified width and height
	 */
	private void drawMouth(double x, double y, 
			double width, double height) {
		add(new GRect(x - width / 2, y - height / 2, width, height));
	}

	/* Parameters */
	private static final double EYE_WIDTH = 0.15;
	private static final double EYE_HEIGHT = 0.15;
	private static final double NOSE_WIDTH = 0.15;
	private static final double NOSE_HEIGHT = 0.10;
	private static final double MOUTH_WIDTH = 0.50;
	private static final double MOUTH_HEIGHT = 0.03;

	/* Constants */
	private static final double FACE_WIDTH = 200;
	private static final double FACE_HEIGHT = 300;
}
