/*
 * File: DrawFace2.java
 * --------------------
 * This program creates a GFace object that uses a GCompound
 * to decompose the object
 */

package demos;

import acm.graphics.*;
import acm.program.*;

/**
 * The DrawFace2 class represents the main program, but the
 * real work in this design is left to the GFace object.
 */

@SuppressWarnings("serial")
public class DrawFace2 extends GraphicsProgram {

	/** Runs the program */
	public void run() {
		face = new GFace(FACE_WIDTH, FACE_HEIGHT);
		add(face, getWidth() / 2, getHeight() / 2);
	}

	/* Constants */
	private static final double FACE_WIDTH = 200;
	private static final double FACE_HEIGHT = 300;
	
	/* Private instance variable */
	private GFace face;
}

	/**
	 * The GFace class represents an abstract graphical rendering
	 * of a face with geometric figures for the eyes, nose, and mouth.
	 */
class GFace extends GCompound {
	
	/** Creates a new instance of the GFace class */
	public GFace(double width, double height) {
		head = new GOval(width, height);	
		leftEye = new GEye(EYE_WIDTH * width, EYE_HEIGHT * height);
		rightEye = new GEye(EYE_WIDTH * width, EYE_HEIGHT * height);
		nose = new GNose(NOSE_WIDTH * width, NOSE_HEIGHT * height);
		mouth = new GMouth(MOUTH_WIDTH * width, MOUTH_HEIGHT * height);
		
		add(head, -width / 2, -height / 2);
		add(leftEye, -0.25 * width, -0.25 * height);
		add(rightEye, 0.25 * width, -0.25 * height);
		add(nose, 0, 0);
		add(mouth, 0, 0.25 * height);
	}
	
	/* Parameters */
	private static final double EYE_WIDTH = 0.15;
	private static final double EYE_HEIGHT = 0.15;
	private static final double NOSE_WIDTH = 0.15;
	private static final double NOSE_HEIGHT = 0.10;
	private static final double MOUTH_WIDTH = 0.50;
	private static final double MOUTH_HEIGHT = 0.03;
	
	/* Private instance variables */
	private GOval head;
	private GEye leftEye, rightEye;
	private GNose nose;
	private GMouth mouth;
}

/**
 * The GEye class represents an eye.  This version subclassess
 * GCompound rather than GOval because doing so provides a simple
 * means to shift the origin to the center of the figure.
 */
class GEye extends GCompound {
	public GEye (double width, double height) {
		add(new GOval(width, height), -width / 2, - height / 2);
	}
}

/**
 * The GNose class represents the nose as a triangular polygon
 */
class GNose extends GPolygon {
	public GNose(double width, double height) {
		addVertex(0, -height / 2);
		addVertex(width / 2, height / 2);
		addVertex(-width / 2, height / 2);
		}
}

/**
 * The GMouth class represents the mouth as a rectangle.  This
 * version subclasses GCompound because doing so provides a simple
 * means to shift the origin to the center of the figure.
 */
class GMouth extends GCompound {
	public GMouth (double width, double height) {
		add(new GRect(width, height), -width / 2, - height / 2);
	}
}
