/*
 * File: StopSign.java
 * -------------------
 * This program draws a stop sign
 */

package demos;

import acm.graphics.*;
import acm.program.*;
import java.awt.*;

/**
 * This class draws a stop sign at the center of the graphics window.
 * The length of an octagon edge is given by the constant EDGE_WIDTH.
 */

@SuppressWarnings("serial")
public class StopSign extends GraphicsProgram {

	/** Stop sign edge length */
	private static final double EDGE_LENGTH = 50;
	
	/** Runs the program */
	public void run() {
		double cx = getWidth() / 2;
		double cy = getHeight() / 2;
		GPolygon octagon = createOctagon(EDGE_LENGTH);
		octagon.setFilled(true);
		octagon.setColor(Color.RED);
		add(octagon, cx, cy);
		GLabel stop = new GLabel("STOP");
		stop.setFont("SansSerif-bold-36");
		stop.setColor(Color.WHITE);
		add(stop, cx - stop.getWidth() / 2, cy + stop.getAscent() / 2);
	}
	
	private GPolygon createOctagon(double side) {
		GPolygon octagon = new GPolygon();
		octagon.addVertex(-side / 2, side / 2 + side / Math.sqrt(2));
		int angle = 0;
		for (int i = 0; i < 8; i++) {
			octagon.addPolarEdge(side, angle);
			angle += 45;
		}
		return octagon;
	}
}
